Name: kernel
Summary: The Linux kernel (the core of the Linux operating system) 

%define sublevel 24
%define kversion 2.6.%{sublevel}

Version: %{kversion}
Release: 1
License: GPL
Group: System Environment/Kernel
Vendor: The Linux Community
Provides: kernel-headers=%{kversion}
URL: http://www.kernel.org
Source: linux-2.6-denx.tar.bz2

BuildRoot: /var/tmp/%{name}-%{PACKAGE_VERSION}-root
BuildArchitectures: noarch


%package source
Summary: The source code for the Linux kernel.
Group: Development/System

%description 
The Linux Kernel, the operating system core itself

%description source
The kernel-source package contains the source code files for the Linux
kernel. These source files are needed to build most C programs, since
they depend on the constants defined in the source code. The source
files can also be used to build a custom kernel that is better tuned
to your particular hardware, if you are so inclined (and you know what
you're doing).

%package headers-%{_targetarch}
Summary: Header files for the Linux kernel for use by glibc
Group: Development/System
Provides: glibc-kernheaders = 3.0-46
%description headers-%{_targetarch}
Kernel-headers includes the C header files that specify the interface
between the Linux kernel and userspace libraries and programs.  The
header files define structures and constants that are needed for
building most standard programs and are also needed for rebuilding the
glibc package.

%prep
%setup -q -n linux-2.6-denx

%ifos solaris2.6
sed -e "s/echo -n .*\.ver/(\$(CONFIG_SHELL) -c '&')/" < Makefile > Makefile.tmp
mv Makefile.tmp Makefile
%endif

%build
%install
mkdir -p $RPM_BUILD_ROOT/usr/src/linux-%{kversion}

tar cf - . | tar xf - -C $RPM_BUILD_ROOT/usr/src/linux-%{kversion}
chmod -R a+r $RPM_BUILD_ROOT/usr/src/linux-%{kversion}

( cd $RPM_BUILD_ROOT/usr/src/linux-%{kversion};
   find . -name .gitignore | xargs rm -f
)

# Install kernel headers

case ${CURRENT_ARCH} in
  ppc)
    hdrarch=powerpc
    ;;
  ppc64)
    hdrarch=powerpc
    ;;
  *)
    hdrarch=$CURRENT_ARCH
    ;;
esac

make ARCH=$hdrarch INSTALL_HDR_PATH=$RPM_BUILD_ROOT/usr headers_install \
 HOSTCC="/usr/bin/gcc -B/usr/bin/"

# Manually go through the 'headers_check' process for every file, but
# don't die if it fails
chmod +x scripts/hdrcheck.sh
echo -e '*****\n*****\nHEADER EXPORT WARNINGS:\n*****' > hdrwarnings.txt
for FILE in `find $RPM_BUILD_ROOT/usr/include` ; do
    scripts/hdrcheck.sh $RPM_BUILD_ROOT/usr/include $FILE /dev/null >> hdrwarnings.txt || :
done
echo -e '*****\n*****' >> hdrwarnings.txt
if grep -q exist hdrwarnings.txt; then
   sed s:^$RPM_BUILD_ROOT/usr/include/:: hdrwarnings.txt
   # Temporarily cause a build failure if header inconsistencies.
   # exit 1
fi

## glibc provides scsi headers for itself, for now
rm -rf $RPM_BUILD_ROOT/usr/include/scsi
#rm -f $RPM_BUILD_ROOT/usr/include/asm*/atomic.h
#rm -f $RPM_BUILD_ROOT/usr/include/asm*/io.h
#rm -f $RPM_BUILD_ROOT/usr/include/asm*/irq.h

%clean
rm -rf $RPM_BUILD_ROOT

%post source
echo "Configuring kernel..."
if [ -z $CROSS_COMPILE ]; then
  echo "CROSS_COMPILE is not set - aborting kernel configuration"
  exit 1
fi
PATH=${RUNTIME_PREFIX}/usr/bin:$PATH
export PATH
# Suppy trailing '-' for CROSS_COMPILE (needed by the kernel Makefile)
CROSS_COMPILE=`echo -n $CROSS_COMPILE | sed -e "s/-\$//"`-
export CROSS_COMPILE
if [ $CURRENT_ARCH = "arm" ]; then
  targetpath="arm"
else
# For all othres it is the CROSS_COMPILE without trailing '-'.
  targetpath=`echo -n $CROSS_COMPILE | sed -e "s/-\$//" -e "s,-linux$,,"`
fi
cd ${RUNTIME_PREFIX}/${targetpath}/usr/src
rm -f linux
ln -snf linux-%{kversion} linux
mkdir -p ${RUNTIME_PREFIX}/${targetpath}/lib/modules/%{kversion}/kernel
touch ${RUNTIME_PREFIX}/${targetpath}/lib/modules/%{kversion}/modules.dep

cd ${RUNTIME_PREFIX}/${targetpath}/usr/src/linux

# For some packages which offer kernel modules, we need configurations
# with CONFIG_MODULES enabled.
TARGET_ARCH=$CURRENT_ARCH
case ${CURRENT_ARCH} in
  arm)
    DEFCONFIG='pxa255-idp_defconfig'
    ;;
  mips)
    DEFCONFIG='yosemite_defconfig'
    ;;
  ppc)
    case ${CROSS_COMPILE} in
        ppc_8xx*)
          DEFCONFIG='mpc885_ads_defconfig'
          TARGET_ARCH='powerpc'
          ;;
        ppc_4xx*)
          DEFCONFIG='ebony_defconfig'
          TARGET_ARCH='powerpc'
          ;;
        ppc_85xx*)
          DEFCONFIG='mpc8544_ds_defconfig'
          TARGET_ARCH='powerpc'
          ;;
        ppc_82xx* | ppc_7xx* | ppc_74xx* | ppc_6xx* | *)
          DEFCONFIG='tqm5200_defconfig'
          TARGET_ARCH='powerpc'
          ;;
    esac
    ;;
  ppc64)
    DEFCONFIG='g5_defconfig'
    TARGET_ARCH='powerpc'
    ;;
  *)
    ;;
esac

make ARCH=$TARGET_ARCH mrproper
if [ -n $DEFCONFIG ]; then
  make ARCH=$TARGET_ARCH $DEFCONFIG HOSTCC="/usr/bin/gcc -B/usr/bin/" | \
   grep -e HOSTCC -e HOSTLD | awk '{print $2}' > /var/tmp/_rmlist
fi
make ARCH=$TARGET_ARCH arch/$TARGET_ARCH/kernel/asm-offsets.s \
 HOSTCC="/usr/bin/gcc -B/usr/bin/" | \
 grep -e HOSTCC -e HOSTLD | awk '{print $2}' >> /var/tmp/_rmlist

# Delete the files of the host archtecture (kernel config aux programs)
for f in `cat /var/tmp/_rmlist`
do
  echo "Removing $f"
  rm -f $f
done

rm -f /var/tmp/_rmlist

echo "Done"

%postun source
linux_path=${RUNTIME_PREFIX}/${targetpath}/usr/src
if [ -L ${linux_path}/linux ]; then 
    if [ -L ${linux_path}/linux -a `ls -l ${linux_path}/linux 2>/dev/null| awk '{ print $11 }'` = "linux-%{kversion}" ]; then
        [ $1 = 0 ] && rm -f ${linux_path}/linux
    fi
fi
exit 0


%files source
%defattr(-,root,root)
/usr/src/linux-%{kversion}

%files headers-%{_targetarch}
%defattr(-,root,root)
/usr/include/*

